pkgmeta = dict(
    __title__='django-mailmate',
    __author__=
    'Chris McKenzie, Matthew Tretter, Colin Wood, Mohammad Taleb, Eric Eldredge',
    __version__='1.3.0', )

globals().update(pkgmeta)
__all__ = tuple(pkgmeta.keys())
